@@ -283,6 +283,10 @@ void write_pwsafe_file(MainView* main) {
 	if (main->file_name==NULL) {
 		main->file_name=interface_file_chooser(main, GTK_FILE_CHOOSER_ACTION_SAVE);
 	}
+	if (main->file_name==NULL) {
+		//file creation canceled
+		return;
+	}
 	main->file_edited=FALSE;
 	/* init vfs just incase... */
 	gnome_vfs_init();
@@ -403,7 +407,7 @@ void writecbc(MainView* mainview, GnomeVFSHandle *handle, BLOWFISH_CTX *blowCTX,
 gboolean pwsafe_file_open_error(MainView *mainview, GnomeVFSResult vfs_result) {
 	if (vfs_result!=GNOME_VFS_OK) {
 		gchar *txt;
-		txt=g_strjoin(NULL, "Failed to Open '", mainview->file_name, "' (", gnome_vfs_result_to_string(vfs_result), ")", NULL);
+		txt=g_strjoin(NULL, _("Failed to Open"), " '", mainview->file_name, "' (", gnome_vfs_result_to_string(vfs_result), ")", NULL);
 		msgbox(mainview, txt);
 		g_free(txt);
 		mainview->file_name=NULL;
@@ -428,6 +432,7 @@ void getV1UserTitle(char *buffer, rec *entry) {
 
 void read_pwsafe_file(MainView* mainview) {
 	gchar *msg;
+	gchar *title;
 	gboolean valid = FALSE;
 	gboolean v2 = TRUE;
 	/* get password */
@@ -435,7 +440,9 @@ void read_pwsafe_file(MainView* mainview) {
 	g_assert(mainview!=NULL);
 	if (!mainview->file_name) return;
 	file_utf8=g_filename_to_utf8(mainview->file_name, -1, NULL, NULL, NULL);
-	mainview->pass=get_password(mainview, file_utf8, PWD_DLG_GET);
+	title = g_strjoin(NULL, _("Password file : "), g_filename_display_basename(file_utf8), NULL);
+	mainview->pass=get_password(mainview, title, PWD_DLG_GET);
+	g_free(title);
 	g_free(file_utf8);
 	
 	if (mainview->pass && mainview->pass[0]) {
@@ -452,7 +459,7 @@ void read_pwsafe_file(MainView* mainview) {
 		gboolean uuiderr=FALSE;
 		SHA1_CTX keyHash;
 		BLOWFISH_CTX blowCTX;
-		rec *entry;
+		rec *entry = NULL;
 		GnomeVFSFileSize filepos;
 
 		/* init vfs just incase... */
@@ -481,7 +488,7 @@ void read_pwsafe_file(MainView* mainview) {
 								buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
 								if (buffer!=NULL) {
 									fileversion=buffer;
-									if (strcmp("2.0", fileversion)!=0) {
+									if (strncmp("2.0", fileversion, 3)!=0) {
 										v2 = FALSE;
 										msg = g_strdup(_("Reading file with version (1.x) \n Will write in 2.0 format"));
 										msgbox(mainview, msg);
@@ -500,7 +507,7 @@ void read_pwsafe_file(MainView* mainview) {
 									} else {
 										if (buffer != NULL) {
 											entry->notes=buffer;
-											entry->group=g_strdup("Group");
+											entry->group=g_strdup(_("Group"));
 											recs=g_list_insert_sorted(recs, entry, (GCompareFunc) rec_comparer);
 										}
 									}
@@ -518,7 +525,7 @@ void read_pwsafe_file(MainView* mainview) {
 													case UUID:
 														if (buffer_len!=16) {
 															if (!uuiderr) {
-																msgbox(mainview, "file error - UUID not 16 bytes. Recreating");
+																msgbox(mainview, _("file error - UUID not 16 bytes. Recreating"));
 															}
 															uuiderr=TRUE;
 															g_free(buffer);
@@ -563,7 +570,7 @@ void read_pwsafe_file(MainView* mainview) {
 														buffer=readcbc(mainview, handle, &blowCTX, iv, &buffer_len, &rec_type);
 														if (buffer != NULL) {
 															entry->notes=buffer;
-															entry->group=g_strdup("Group");
+															entry->group=g_strdup(_("Group"));
 															recs=g_list_insert_sorted(recs, entry, (GCompareFunc) rec_comparer);
 															entry=g_malloc0(sizeof(rec));
 															entry->uuid=entry->group=entry->title=entry->user=entry->notes=entry->password=NULL;
