@@ -49,7 +49,7 @@
 #define _(String) gettext(String)
 
 #define APP_NAME "pwsafe"
-#define APP_VER "1.4.0"
+#define APP_VER "1.6.0"
 
 extern void save_mod_file(MainView *mainview);
 extern void close_file(MainView *mainview);
@@ -112,12 +112,12 @@ int main( int argc, char* argv[] ) {
 	interface_show_state(main_view);
 		
 	main_view->last_file=conf_get_string(CONF_LASTFILE);
-	g_signal_emit_by_name(G_OBJECT(main_view->open_last_item), "activate");
+	interfaceCallLastItem(main_view) ;
 	
 	gtk_main();
 
 	/* Clean up */
-    save_mod_file(main_view);
+	save_mod_file(main_view);
 	close_file(main_view);
 	osso_deinitialize(data->osso);
 	interface_main_view_destroy ( main_view );
